Stan Math Library: stan/math/fwd/scal/fun/modified_bessel_second_kind.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

modified_bessel_second_kind.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_MODIFIED_BESSEL_SECOND_KIND_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_MODIFIED_BESSEL_SECOND_KIND_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/modified_bessel_second_kind.hpp>
7
8 namespace stan {
9
10 namespace math {
11
12 template <typename T>
13 inline
14 fvar<T>
15 modified_bessel_second_kind(int v, const fvar<T>& z) {
16 using stan::math::modified_bessel_second_kind;
17
18 T modified_bessel_second_kind_z(modified_bessel_second_kind(v, z.val_));
19 return fvar<T>(modified_bessel_second_kind_z,
20 -v * z.d_ * modified_bessel_second_kind_z / z.val_
21 - z.d_ * modified_bessel_second_kind(v - 1, z.val_));
22 }
23 }
24 }
25 #endif
stan::math::modified_bessel_second_kind
fvar< T > modified_bessel_second_kind(int v, const fvar< T > &z)
Definition: modified_bessel_second_kind.hpp:15
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan
Definition: log_sum_exp.hpp:8
modified_bessel_second_kind.hpp
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.